@@ -21,58 +21,71 @@ SEQUENCE_AXIS = -2
 
 
 class PositionEmbedding(keras.layers.Layer):
-    """Creates a layer which learns a position embedding for inputs sequences.
+    """A layer which learns a position embedding for inputs sequences.
 
     This class assumes that in the input tensor, the last dimension corresponds
     to the features, and the dimension before the last corresponds to the
     sequence.
 
-    This class accepts `RaggedTensor`s as inputs to process batches of sequences
-    of different lengths. The one ragged dimension must be the dimension that
-    corresponds to the sequence, that is, the penultimate dimension.
+    This layer optionally accepts `tf.RaggedTensor`s as inputs to process
+    batches of sequences of different lengths. The one ragged dimension must be
+    the dimension that corresponds to the sequence, that is, the penultimate
+    dimension.
+
+    This layer does not supporting masking, but can be combined with a
+    `keras.layers.Embedding` for padding mask support.
 
     Args:
-        max_length: The maximum length of the dynamic sequence.
+        sequence_length: The maximum length of the dynamic sequence.
         initializer: The initializer to use for the embedding weights. Defaults
-            to "glorot_uniform".
+            to `"glorot_uniform"`.
         seq_axis: The axis of the input tensor where we add the embeddings.
 
-    Example:
-    ```python
-    token_embeddings = layers.Embedding(
-        input_dim=vocab_size, output_dim=embed_dim
-    )
-    position_embeddings = keras_nlp.layers.PositionEmbedding(
-        max_length=max_length
-    )
+    Examples:
 
-    embedded_tokens = token_embeddings(inputs)
-    embedded_positions = position_embeddings(embedded_tokens)
-    outputs = embedded_tokens + embedded_positions
+    Called directly on input.
+    >>> layer = keras_nlp.layers.PositionEmbedding(sequence_length=10)
+    >>> layer(tf.zeros((8, 10, 16))).shape
+    TensorShape([8, 10, 16])
+
+    Combine with a token embedding.
+    ```python
+    seq_length = 50
+    vocab_size = 5000
+    embed_dim = 128
+    inputs = keras.Input(shape=(seq_length,))
+    token_embeddings = keras.layers.Embedding(
+        input_dim=vocab_size, output_dim=embed_dim
+    )(inputs)
+    position_embeddings = keras_nlp.layers.PositionEmbedding(
+        sequence_length=seq_length
+    )(token_embeddings)
+    outputs = token_embeddings + position_embeddings
     ```
 
     Reference:
-        [BERT: Pre-training of Deep Bidirectional Transformers for Language
-        Understanding](https://arxiv.org/abs/1810.04805).
+     - [Devlin et al., 2019](https://arxiv.org/abs/1810.04805)
     """
 
     def __init__(
         self,
-        max_length,
+        sequence_length,
         initializer="glorot_uniform",
         **kwargs,
     ):
         super().__init__(**kwargs)
-        if max_length is None:
-            raise ValueError("`max_length` must be an Integer, not `None`.")
-        self.max_length = int(max_length)
+        if sequence_length is None:
+            raise ValueError(
+                "`sequence_length` must be an Integer, received `None`."
+            )
+        self.sequence_length = int(sequence_length)
         self.initializer = keras.initializers.get(initializer)
 
     def get_config(self):
         config = super().get_config()
         config.update(
             {
-                "max_length": self.max_length,
+                "sequence_length": self.sequence_length,
                 "initializer": keras.initializers.serialize(self.initializer),
             }
         )
@@ -82,7 +95,7 @@ class PositionEmbedding(keras.layers.Layer):
         feature_size = input_shape[-1]
         self.position_embeddings = self.add_weight(
             "embeddings",
-            shape=[self.max_length, feature_size],
+            shape=[self.sequence_length, feature_size],
             initializer=self.initializer,
             trainable=True,
         )
@@ -106,8 +119,9 @@ class PositionEmbedding(keras.layers.Layer):
             )
 
     def _trim_and_broadcast_position_embeddings(self, shape):
-        sequence_length = shape[SEQUENCE_AXIS]
-        # trim to match the length of the sequence
-        position_embeddings = self.position_embeddings[:sequence_length, :]
+        input_length = shape[SEQUENCE_AXIS]
+        # trim to match the length of the input sequence, which might be less
+        # than the sequence_length of the layer.
+        position_embeddings = self.position_embeddings[:input_length, :]
         # then broadcast to add the missing dimensions to match "shape"
         return tf.broadcast_to(position_embeddings, shape)
